==> 5.8.0.tar.gz: ciphey/translations/nl/CONTRIBUTING.md <==
Hey daar! 

Dus je bent geïnteresseerd om bij te dragen aan Ciphey? 🤔

Misschien weet u niet waar u moet beginnen, of denkt u dat uw programmeervaardigheden niet "goed genoeg" zijn? Nou, voor het laatste - dat is belachelijk! We zijn helemaal in orde met "slechte code" en zelfs dan, als je dit document leest, ben je waarschijnlijk een geweldige programmeur. Ik bedoel, nieuwelingen leren niet vaak om bij te dragen aan GitHub-projecten 😉


Hier zijn enkele manieren waarop u kunt bijdragen aan Ciphey:
* Voeg een nieuwe taal toe 🧏
* Voeg meer encryptiemethoden toe 📚
* Maak meer documentatie (erg belangrijk! We zouden je eeuwig dankbaar zijn)
* Fix bugs die zijn ingediend via GitHub Issues (we kunnen u hierbij ondersteunen 😊)
* Refactor de codebase 🥺

Als deze moeilijk klinken, hoeft u zich geen zorgen te maken! In dit document wordt precies uitgelegd hoe u elk van deze kunt bereiken. Je naam wordt ook toegevoegd aan de lijst met bijdragers van Ciphey, en we zullen je eeuwig dankbaar zijn! 🙏

We hebben een kleine Discord-chatroom om met de ontwikkelaars te praten en hulp te krijgen. U kunt ook een GitHub Issue schrijven voor uw suggestie. Als je aan de Discord wilt worden toegevoegd, stuur ons dan een DM of vraag het ons op een of andere manier.
[Discord Server](https://discord.gg/KfyRUWw)

# Hoe u kunt bijdragen
Ciphey heeft altijd meer decoderingstools nodig! Voor meer informatie over het integreren van code in ciphey, ga je naar:
* https://github.com/Ciphey/Ciphey/wiki/Adding-your-own-ciphers voor een simpele tutorial
* https://github.com/Ciphey/Ciphey/wiki/Extending-Ciphey voor een API-referentie

Het zou leuk zijn als je er enkele tests voor zou schrijven, door simpelweg een functie in de Ciphey/tests/test_main.py te kopiëren en de cijfertekst te vervangen door iets dat met je cipher is gecodeerd. Als u geen tests toevoegt, zullen we deze waarschijnlijk nog steeds merge,, maar het zal veel moeilijker voor ons zijn om bugs te vinden!

Het is vanzelfsprekend dat we u voor uw harde werk aan de lijst met bijdragers zullen toevoegen!

# Voeg een nieuwe taal toe 🧏
De standaard taalcontrole, `brandon`, werkt met meerdere talen. Dit klinkt misschien ontmoedigend.
Maar eerlijk gezegd hoef je alleen maar een woordenboek te nemen, een kleine analyse uit te voeren (we hebben code geschreven om je hierbij te helpen), de woordenboeken en analyse toe te voegen aan een repository. En voeg dan de optie toe aan `settings.yml`.

# Maak meer documentatie
Documentatie is het belangrijkste onderdeel van Ciphey. Geen enkele documentatie is een extreme 'codeschuld', en dat willen we niet.

Geloof me wanneer ik zeg dat als je bijdraagt aan geweldige documentatie, je op hetzelfde niveau wordt gezien als codebijdragers. Documentatie is absoluut essentieel.

Er zijn veel manieren waarop u documentatie kunt toevoegen.
* Doc strings in de code
* Verbeteren van onze huidige documentatie (README, dit bestand, onze Ciphey Wiki pagina's)
* Vertalen van documentatie

En nog veel meer!

# Fix bugs
Bezoek onze GitHub-problemenpagina om alle bugs te vinden die Ciphey heeft! Fix ze en je wordt toegevoegd aan de lijst met bijdragers. ;)

# Refactor de codebase
Niet alle Ciphey volgt PEP8, en een deel van de code wordt herhaald.

==> 5.10.0.tar.gz: ciphey/translations/nl/CONTRIBUTING.md <==
Hey daar!

Dus je bent geïnteresseerd om bij te dragen aan Ciphey? 🤔

Misschien weet u niet waar u moet beginnen, of denkt u dat uw programmeervaardigheden niet "goed genoeg" zijn? Nou, voor het laatste - dat is belachelijk! We zijn helemaal in orde met "slechte code" en zelfs dan, als je dit document leest, ben je waarschijnlijk een geweldige programmeur. Ik bedoel, nieuwelingen leren niet vaak om bij te dragen aan GitHub-projecten 😉

Hier zijn enkele manieren waarop u kunt bijdragen aan Ciphey:

- Voeg een nieuwe taal toe 🧏
- Voeg meer encryptiemethoden toe 📚
- Maak meer documentatie (erg belangrijk! We zouden je eeuwig dankbaar zijn)
- Fix bugs die zijn ingediend via GitHub Issues (we kunnen u hierbij ondersteunen 😊)
- Refactor de codebase 🥺

Als deze moeilijk klinken, hoeft u zich geen zorgen te maken! In dit document wordt precies uitgelegd hoe u elk van deze kunt bereiken. Je naam wordt ook toegevoegd aan de lijst met bijdragers van Ciphey, en we zullen je eeuwig dankbaar zijn! 🙏

We hebben een kleine Discord-chatroom om met de ontwikkelaars te praten en hulp te krijgen. U kunt ook een GitHub Issue schrijven voor uw suggestie. Als je aan de Discord wilt worden toegevoegd, stuur ons dan een DM of vraag het ons op een of andere manier.
[Discord Server](https://discord.gg/KfyRUWw)

# Hoe u kunt bijdragen

Ciphey heeft altijd meer decoderingstools nodig! Voor meer informatie over het integreren van code in ciphey, ga je naar:

- <https://github.com/Ciphey/Ciphey/wiki/Adding-your-own-ciphers> voor een simpele tutorial
- <https://github.com/Ciphey/Ciphey/wiki/Extending-Ciphey> voor een API-referentie

Het zou leuk zijn als je er enkele tests voor zou schrijven, door simpelweg een functie in de Ciphey/tests/test_main.py te kopiëren en de cijfertekst te vervangen door iets dat met je cipher is gecodeerd. Als u geen tests toevoegt, zullen we deze waarschijnlijk nog steeds merge,, maar het zal veel moeilijker voor ons zijn om bugs te vinden!

Het is vanzelfsprekend dat we u voor uw harde werk aan de lijst met bijdragers zullen toevoegen!

# Voeg een nieuwe taal toe 🧏

De standaard taalcontrole, `brandon`, werkt met meerdere talen. Dit klinkt misschien ontmoedigend.
Maar eerlijk gezegd hoef je alleen maar een woordenboek te nemen, een kleine analyse uit te voeren (we hebben code geschreven om je hierbij te helpen), de woordenboeken en analyse toe te voegen aan een repository. En voeg dan de optie toe aan `settings.yml`.

# Maak meer documentatie

Documentatie is het belangrijkste onderdeel van Ciphey. Geen enkele documentatie is een extreme 'codeschuld', en dat willen we niet.

Geloof me wanneer ik zeg dat als je bijdraagt aan geweldige documentatie, je op hetzelfde niveau wordt gezien als codebijdragers. Documentatie is absoluut essentieel.

Er zijn veel manieren waarop u documentatie kunt toevoegen.

- Doc strings in de code
- Verbeteren van onze huidige documentatie (README, dit bestand, onze Ciphey Wiki pagina's)
- Vertalen van documentatie

En nog veel meer!

# Fix bugs

Bezoek onze GitHub-problemenpagina om alle bugs te vinden die Ciphey heeft! Fix ze en je wordt toegevoegd aan de lijst met bijdragers. ;)

# Refactor de codebase

Niet alle Ciphey volgt PEP8, en een deel van de code wordt herhaald.
